pub(crate) struct BatchProofMethodId {
pub body: BatchProofMethodIdBody,
pub signatures_with_index: [([u8; 64], u8); 3],
}Expand description
A new batch proof method_id starting to be applied from the l2_block_number (inclusive).
Fields
body: BatchProofMethodIdBodyBody of the method id update, the message to be signed Includes method id and activation height
signatures_with_index: [([u8; 64], u8); 3]Signatures to be verified for the method id update used for a 3 of 5 security council Consists of 64 byte keccak256(eip191 prefixed message) prehash signed signatures The public keys can be recovered from the signatures and the prehash The indices point to the pubkeys in the light client circuit initial values To verify the signature the pubkey should be fetched from the initial values corresponding to the signature If one signature verification fails the whole method id update is invalid Also assumes the indexes are in ascending order and there are no duplicates